@@ -2,12 +2,10 @@
 """
 Input plug-in for a KKR calculation.
 """
-from __future__ import print_function, absolute_import
-from __future__ import unicode_literals
 import os
 import numpy as np
 from aiida.engine import CalcJob
-from aiida.orm import CalcJobNode, load_node, RemoteData, Dict, StructureData, KpointsData, Bool
+from aiida.orm import CalcJobNode, load_node, RemoteData, Dict, StructureData, KpointsData, Bool, FolderData
 from .voro import VoronoiCalculation
 from ..tools.common_workfunctions import get_natyp
 from aiida.common.utils import classproperty
@@ -21,13 +19,11 @@ from masci_tools.io.common_functions import get_alat_from_bravais, get_Ang2aBohr
 from aiida_kkr.tools.tools_kkrimp import make_scoef, write_scoef_full_imp_cls
 from aiida_kkr.tools.find_parent import find_parent_structure
 from masci_tools.io.kkr_params import __kkr_default_params__, kkrparams
-import six
-from six.moves import range
 
 __copyright__ = (u'Copyright (c), 2017, Forschungszentrum Jülich GmbH, '
                  'IAS-1/PGI-1, Germany. All rights reserved.')
 __license__ = 'MIT license, see LICENSE.txt file'
-__version__ = '0.12.2'
+__version__ = '0.12.5'
 __contributors__ = ('Jens Bröder', 'Philipp Rüßmann')
 
 verbose = False
@@ -55,6 +51,7 @@ class KkrCalculation(CalcJob):
     # List of optional input files (may be mandatory for some settings in inputcard)
     _SHAPEFUN = 'shapefun'  # mandatory if nonspherical calculation
     _SCOEF = 'scoef'  # mandatory for KKRFLEX calculation and some functionalities
+    _BFIELD = 'bfield.dat'  # mandatory if <NONCOBFIELD>= True
     _NONCO_ANGLES = 'nonco_angle.dat'  # mandatory if noncollinear directions are used that are not (theta, phi)= (0,0) for all atoms
     _NONCO_ANGLES_IMP = 'nonco_angle_imp.dat'  # mandatory for GREENIMP option (scattering code)
     _SHAPEFUN_IMP = 'shapefun_imp'  # mandatory for GREENIMP option (scattering code)
@@ -101,6 +98,7 @@ class KkrCalculation(CalcJob):
     _DECIFILE = 'decifile'
     # BdG mode
     _BDG_POT = 'den_lm_ir.%0.3i.%i.txt'
+    _BDG_CHI_NS = 'den_lm_ns_*.npy'
 
     # template.product entry point defined in setup.json
     _default_parser = 'kkr.kkrparser'
@@ -145,22 +143,12 @@ class KkrCalculation(CalcJob):
         # now define input files and parser
         spec.input(
             'metadata.options.parser_name',
-            valid_type=six.string_types,
+            valid_type=str,
             default=cls._default_parser,
             non_db=True,
         )
-        spec.input(
-            'metadata.options.input_filename',
-            valid_type=six.string_types,
-            default=cls._DEFAULT_INPUT_FILE,
-            non_db=True
-        )
-        spec.input(
-            'metadata.options.output_filename',
-            valid_type=six.string_types,
-            default=cls._DEFAULT_OUTPUT_FILE,
-            non_db=True
-        )
+        spec.input('metadata.options.input_filename', valid_type=str, default=cls._DEFAULT_INPUT_FILE, non_db=True)
+        spec.input('metadata.options.output_filename', valid_type=str, default=cls._DEFAULT_OUTPUT_FILE, non_db=True)
 
         # define input nodes (optional ones have required=False)
         spec.input(
@@ -215,6 +203,25 @@ class KkrCalculation(CalcJob):
             equal to the number of atoms.
             """
         )
+        spec.input(
+            'bfield',
+            valid_type=Dict,
+            required=False,
+            help="""Non-collinear exteral B-field used for constraint calculations.
+
+            The Dict node should be of the form
+            initial_noco_angles = Dict(dict={
+                'theta': [theta_at1, theta_at2, ..., theta_atN],
+                # list theta values in degrees (0..180)
+                'phi': [phi_at1, phi_at2, ..., phi_atN],
+                # list phi values in degrees (0..360)
+                'magnitude': [magnitude at_1, ..., magnitude at_N]
+                # list of magnitude of the applied fields in Ry units
+            })
+            Note: The length of the theta, phi and magnitude lists have to be
+            equal to the number of atoms.
+            """
+        )
         spec.input(
             'deciout_parent',
             valid_type=RemoteData,
@@ -230,6 +237,15 @@ class KkrCalculation(CalcJob):
             the kkrflex_* files are copied to the retrieved (can clutter the
             database) or are ony left in the remote folder."""
         )
+        spec.input(
+            'anomalous_density',
+            valid_type=FolderData,
+            required=False,
+            help="""FolderData that contains anomalous density input files for
+            the KKRhost BdG calculation. If these are not give the code looks
+            for them in the retrieved of the parent calculation and takes them
+            from there."""
+        )
 
         # define outputs
         spec.output(
@@ -295,6 +311,10 @@ class KkrCalculation(CalcJob):
         if 'initial_noco_angles' in self.inputs:
             parameters = self._use_initial_noco_angles(parameters, structure, tempfolder)
 
+        # write bfield.dat file and add '<NONCOBFIELD>= True' to input parameters
+        if 'bfield' in self.inputs:
+            parameters = self._use_nonco_bfield(parameters, structure, tempfolder)
+
         # activate decimation mode and copy decifile from deciout parent
         if 'deciout_parent' in self.inputs:
             parameters = self._use_decimation(parameters, tempfolder)
@@ -802,10 +822,13 @@ class KkrCalculation(CalcJob):
             self.report(f'retrieve BdG? {retrieve_BdG_files}')
 
         if retrieve_BdG_files:
+            # anomalous density files for all atoms if present
             for iatom in range(natom):
                 for ispin in range(nspin):
                     print('adding files for BdG mode')
                     add_files += [self._BDG_POT % (iatom + 1, ispin + 1)]
+            # radially-averaged anomalous density matrix (for triplet components etc.)
+            add_files.append(self._BDG_CHI_NS)
 
             #also retrieve BdG DOS files for anomalous density and hole part
             for BdGadd in ['_eh', '_he', '_hole']:
@@ -1015,6 +1038,51 @@ class KkrCalculation(CalcJob):
 
         return parameters
 
+    def _use_nonco_bfield(self, parameters, structure, tempfolder):
+        """
+        Set external non-collinear bfield (writes bfield.dat to tempfolder) used in constraint calculations.
+        """
+        self.report('Found `bfield` input node, writing nonco_angle.dat file')
+
+        # extract number of atoms for length comparison
+        natom = get_natyp(structure)
+
+        change_values = [['<NONCOBFIELD>', True]]
+        parameters = _update_params(parameters, change_values)
+
+        # extract magnitude, theta and phi values from input node
+        mags = self.inputs.bfield['magnitude']
+        if len(mags) != natom:
+            raise InputValidationError(
+                'Error: `magnitude` list in `bfield` input node needs to have the same length as number of atoms!'
+            )
+        thetas = self.inputs.bfield['theta']
+        if len(thetas) != natom:
+            raise InputValidationError(
+                'Error: `theta` list in `bfield` input node needs to have the same length as number of atoms!'
+            )
+        phis = self.inputs.bfield['phi']
+        if len(phis) != natom:
+            raise InputValidationError(
+                'Error: `phi` list in `bfield` input node needs to have the same length as number of atoms!'
+            )
+
+        # now write kkrflex_angle file
+        with tempfolder.open(self._BFIELD, 'w') as bfield_file:
+            bfield_file.write('# theta [deg]  phi [deg]  magnitude [Ry]\n')
+            for iatom in range(natom):
+                theta, phi = thetas[iatom], phis[iatom]
+                magnitude = mags[iatom]
+                # check consistency
+                if theta < 0. or theta > 180.:
+                    raise InputValidationError(
+                        f'Error: theta value out of range (0..180): iatom={iatom}, theta={theta}'
+                    )
+                # write line
+                bfield_file.write(f'   {theta}    {phi}    {magnitude}\n')
+
+        return parameters
+
     def _use_decimation(self, parameters, tempfolder):
         """
         Activate decimation mode and copy decifile from output of deciout_parent calculation
@@ -1063,13 +1131,26 @@ class KkrCalculation(CalcJob):
         Activate BdG mode and copy den_lm_ir files of the previous output to the input of this calculation.
         """
 
-        BDG_POT_FILES = [i for i in retrieved.list_object_names() if self._BDG_POT.split('.')[0] in i]
+        if 'anomalous_density' in self.inputs:
+            # this means we have a FolderData input that contains the
+            # anomalous density files
+            adens_folder = self.inputs.anomalous_density
+        else:
+            # if no anomalous density is given as an input node we check
+            # if there are any anomalous density files in the parent retrieved
+            # and take them from there if present
+            adens_folder = retrieved
+
+        # list of den_lm_ir files (anomalous density per atom)
+        BDG_POT_FILES = [i for i in adens_folder.list_object_names() if self._BDG_POT.split('.')[0] in i]
 
         # add 'den-lm_ir' files to input
         for BdG_pot in BDG_POT_FILES:
-            self.report(f'Copy BdG potential {BdG_pot}')
-            with retrieved.open(BdG_pot, 'r') as file_handle:
+            self.report(f'Copy BdG potential {BdG_pot} from {adens_folder.uuid}')
+            # read from parent
+            with adens_folder.open(BdG_pot, 'r') as file_handle:
                 file_txt = file_handle.readlines()
+            # write to tempfolder
             with tempfolder.open(BdG_pot, 'w') as file_handle:
                 file_handle.writelines(file_txt)
 
@@ -1086,7 +1167,7 @@ def _update_params(parameters, change_values):
             new_params[key] = val
         for key, val in change_values:
             new_params[key] = val
-        new_params_node = Dict(dict=new_params)
+        new_params_node = Dict(new_params)
         #parameters = update_params_wf(parameters, new_params_node)
         parameters = new_params_node
     return parameters
