@@ -8,7 +8,6 @@ Created on Mon Dec 13 14:38:59 2021
 
 # -*- coding: utf-8 -*-
 
-from __future__ import absolute_import
 from aiida.parsers.parser import Parser
 from aiida.orm import Dict, CalcJobNode
 from aiida_kkr.calculations.kkrnano import KKRnanoCalculation
@@ -296,7 +295,7 @@ class KKRnanoParser(Parser):
                 block_dict[final_DOS_captions[p]] = DOS_block[:, p]
 
             if multipleSpins:
-                dict_dos[spin_list[i]] = block_dict
+                dict_dos[spin_list[i]] = block_dict  # pylint: disable=used-before-assignment
             else:
                 dict_dos = block_dict
             #DOS_blocks.append(DOS_block)
