@@ -2,13 +2,10 @@
 """
 contains plot_kkr class for node visualization
 """
-from __future__ import print_function
-from __future__ import division
-from __future__ import absolute_import
+
 import numpy as np
 import matplotlib.pyplot as plt
 from builtins import object, str
-from six.moves import range
 from ..tools.common_workfunctions import get_natyp
 from masci_tools.io.common_functions import search_string
 import numpy as np
@@ -16,7 +13,7 @@ import numpy as np
 __copyright__ = (u'Copyright (c), 2018, Forschungszentrum Jülich GmbH, '
                  'IAS-1/PGI-1, Germany. All rights reserved.')
 __license__ = 'MIT license, see LICENSE.txt file'
-__version__ = '0.7.0'
+__version__ = '0.7.1'
 __contributors__ = ('Philipp Rüßmann')
 
 
@@ -1896,7 +1893,7 @@ def get_ef_from_parent(node):
     except:
         with node.outputs.retrieved.open('output.0.txt', mode='r') as file_handle:
             txt = file_handle.readlines()
-            iline = search_string('Fermi energy', txt)
+            iline = search_string('Fermi energy =', txt)
             if iline >= 0:
                 ef = txt[iline].split('=')[1]
                 ef = float(ef.split()[0])
@@ -1935,10 +1932,11 @@ def get_qdos_filenames(node):
 
 def get_qdos_data_from_node(node, qdos_filenames):
     """Extract the qdos data (summed over all atoms)"""
+    from aiida import orm
 
-    if 'saved_dispersion_data' in node.extras:
+    if 'saved_dispersion_data_uuid' in node.extras:
         # only return the existing numpy array if it exists
-        data = np.array(node.extras['saved_dispersion_data'])
+        data = orm.load_node(node.extras['saved_dispersion_data_uuid']).get_array('data')
     else:
         # read qdos data and store as extra
         for i, fname in enumerate(qdos_filenames):
@@ -1958,6 +1956,10 @@ def get_qdos_data_from_node(node, qdos_filenames):
                     data[:, 4:] += tmp[:, 4:]
 
         # now store as extra
-        node.set_extra('saved_dispersion_data', data)
+        # TODO: make this nicer and connect to provenance graph with calcfunction
+        data_node = orm.ArrayData()
+        data_node.set_array('data', data)
+        data_node.store()
+        node.set_extra('saved_dispersion_data_uuid', data_node.uuid)
 
     return data
