@@ -3,13 +3,8 @@
 """
 Tools for the impurity caluclation plugin and its workflows
 """
-from __future__ import print_function
-from __future__ import division
-from __future__ import absolute_import
-from __future__ import unicode_literals
+
 from builtins import object, str
-from six.moves import range
-from six.moves import input
 from masci_tools.io.common_functions import open_general
 from masci_tools.io.common_functions import search_string
 import numpy as np
@@ -259,9 +254,13 @@ def get_structure_data(structure):
         naez = n - m
         m = m - 1
         #convert the element symbol from StructureData to the charge number
-        for ikind in range(len(sitekind.symbols)):
-            site_symbol = sitekind.symbols[ikind]
-            charges.append(_atomic_numbers[site_symbol])
+        if sitekind.get_symbols_string() == '{H0.00X1.00}':
+            # special case when HX is mistaken for H instead of X
+            charges.append(0.0)
+        else:
+            for ikind in range(len(sitekind.symbols)):
+                site_symbol = sitekind.symbols[ikind]
+                charges.append(_atomic_numbers[site_symbol])
         i = len(charges) - 1
         a[k][3] = int(naez)
         a[k][4] = float(charges[i])
