@@ -3,8 +3,6 @@
 This module contains the workflow which combines pre-converged two single-impurity calculations to a larger impurity calculation
 """
 
-from __future__ import absolute_import
-from __future__ import print_function
 from aiida.engine import WorkChain, if_, ToContext, calcfunction
 from aiida.orm import load_node, Dict, WorkChainNode, Int, RemoteData, Bool, ArrayData
 from aiida_kkr.calculations import KkrCalculation, KkrimpCalculation
@@ -77,7 +75,6 @@ class combine_imps_wc(WorkChain):
     _workflowversion = __version__
     _wf_default = {
         'jij_run': False,  # Any kind of addition in _wf_default should be updated into the start() as well.
-        'retrieve_kkrflex': False,
     }
 
     @classmethod
@@ -89,7 +86,11 @@ class combine_imps_wc(WorkChain):
         """
         if not silent:
             print(f'Version of workflow: {cls._workflowversion}')
-        return cls._wf_default.copy()
+        return {
+            'global': cls._wf_default.copy(),
+            'scf': kkr_imp_sub_wc.get_wf_defaults(),
+            'ghost_gf': kkr_flex_wc.get_wf_defaults()
+        }
 
     @classmethod
     def define(cls, spec):
@@ -111,6 +112,7 @@ class combine_imps_wc(WorkChain):
                 'kkr',
                 'options',
                 'params_kkr_overwrite',
+                'wf_parameters',
             ),  # expose only those port which are not set automatically
             namespace_options={
                 'required': False,
@@ -225,8 +227,6 @@ If given then the writeout step of the host GF is omitted."""
         self.report(message)
         if 'wf_parameters_overwrite' in self.inputs:
             self.ctx.wf_parameters_overwrite = self.inputs.wf_parameters_overwrite
-        # wf_parameters_flex to keep upto time the  gf_writeout_step
-        self.ctx.wf_parameters_flex = {'retrieve_kkrflex': False}
 
         self.ctx.run_options = {'jij_run': False}
         self.ctx.imp1 = self.get_imp_node_from_input(iimp=1)
@@ -566,12 +566,14 @@ If given then the writeout step of the host GF is omitted."""
         Write out the host GF
         """
 
-        wf_parameters_flex = self.ctx.wf_parameters_flex
         # create process builder for gf_writeout workflow
         builder = kkr_flex_wc.get_builder()
         builder.impurity_info = self.ctx.imp_info_combined
         builder.kkr = self.inputs.host_gf.kkr
-        builder.wf_parameters = Dict(dict=wf_parameters_flex)
+
+        if 'wf_parameters' in self.inputs.host_gf:
+            self.report(f'set wf_parameters {self.inputs.host_gf.wf_parameters.get_dict()}')
+            builder.wf_parameters = self.inputs.host_gf.wf_parameters
 
         if 'options' in self.inputs.host_gf:
             builder.options = self.inputs.host_gf.options
@@ -656,7 +658,11 @@ If given then the writeout step of the host GF is omitted."""
         """
 
         scf_wf_parameters = self.ctx.scf_wf_parameters.get_dict()
-        wf_parameters_flex = self.ctx.wf_parameters_flex
+
+        if 'wf_parameters' in self.inputs.host_gf:
+            wf_parameters_flex = self.inputs.host_gf.wf_parameters.get_dict()
+        else:
+            wf_parameters_flex = {}
         run_options = self.ctx.run_options
         # Update the scf_wf_parameters from the wf_parameters_overwrite
         if 'wf_parameters_overwrite' in self.inputs:
@@ -694,7 +700,7 @@ If given then the writeout step of the host GF is omitted."""
 
         self.ctx.run_options = run_options
         self.ctx.wf_parameters_flex = wf_parameters_flex
-        self.ctx.scf_wf_parameters = Dict(dict=scf_wf_parameters)
+        self.ctx.scf_wf_parameters = Dict(scf_wf_parameters)
 
     def run_kkrimp_scf(self):
         """
@@ -768,7 +774,7 @@ If given then the writeout step of the host GF is omitted."""
         param_dict = {k: v for k, v in builder.parameters.get_dict().items() if v is not None}
         param_dict['CALCJIJMAT'] = 1  # activate Jij calculation, leave the rest as is
 
-        builder.parameters = Dict(dict=param_dict)
+        builder.parameters = Dict(param_dict)
         builder.metadata.label = 'KKRimp_Jij (' + last_calc.label.split('=')[1][3:]
 
         future = self.submit(builder)
@@ -1020,4 +1026,4 @@ def parse_Jij(retrieved, impurity_info, impurity1_output_node, impurity2_output_
     a = ArrayData()
     a.set_array('JijData', plotdata)
 
-    return {'Jijdata': a, 'info': Dict(dict={'text': out_txt})}
+    return {'Jijdata': a, 'info': Dict({'text': out_txt})}
