@@ -19,7 +19,7 @@ from masci_tools.util.constants import BOHR_A
 __copyright__ = (u'Copyright (c), 2022, Forschungszentrum Jülich GmbH, '
                  'IAS-1/PGI-1, Germany. All rights reserved.')
 __license__ = 'MIT license, see LICENSE.txt file'
-__version__ = '0.1.0'
+__version__ = '0.1.1'
 __contributors__ = (u'Philipp Rüßmann')
 
 
@@ -217,7 +217,7 @@ class kkr_jij_wc(WorkChain):
 
         # set Jij parameters
         para_jij, runopts = self._get_para_jij(params)
-        updatenode = Dict(dict=para_jij.get_dict())
+        updatenode = Dict(para_jij.get_dict())
         updatenode.label = 'Jij params'
         paranode_jij = update_params_wf(params, updatenode)
         self.ctx.jij_params = paranode_jij
@@ -324,7 +324,7 @@ class kkr_jij_wc(WorkChain):
         outputnode_dict['successful'] = success
 
         # create output node with data-provenance
-        outputnode = Dict(dict=outputnode_dict)
+        outputnode = Dict(outputnode_dict)
 
         # link to the output nodes
         link_nodes = outdict.copy()
@@ -359,25 +359,25 @@ class kkr_jij_wc(WorkChain):
         para_jij.set_value('NSTEPS', 1)  # one-shot run
 
         # accuracy settings
-        tempr = self.ctx.wf_dict['accuracy'].get('TEMPR')
+        tempr = self.ctx.wf_dict.get('accuracy', {}).get('TEMPR')
         if tempr is not None:
             para_jij.set_value('TEMPR', tempr)  # slightly reduce temperature
 
-        rclustz = self.ctx.wf_dict['accuracy'].get('RCLUSTZ')
+        rclustz = self.ctx.wf_dict.get('accuracy', {}).get('RCLUSTZ')
         if rclustz is not None:
             para_jij.set_value('RCLUSTZ', rclustz)  # increase cluster radius
 
-        kmesh = self.ctx.wf_dict['accuracy'].get('kmesh')
+        kmesh = self.ctx.wf_dict.get('accuracy', {}).get('kmesh')
         if kmesh is not None:
             para_jij.set_value('BZDIVIDE', kmesh)  # increase k-points
             para_jij.set_value('KPOIBZ', np.product(kmesh))  # array dimension
 
         # array dimensions
-        NATOMIMPD = self.ctx.wf_dict['accuracy'].get('NATOMIMPD')
+        NATOMIMPD = self.ctx.wf_dict.get('accuracy', {}).get('NATOMIMPD')
         if NATOMIMPD is not None:
             para_jij.set_value('NATOMIMPD', NATOMIMPD)  # array dimension
 
-        NSHELD = self.ctx.wf_dict['accuracy'].get('NSHELD')
+        NSHELD = self.ctx.wf_dict.get('accuracy', {}).get('NSHELD')
         if NSHELD is not None:
             para_jij.set_value('NSHELD', NSHELD)  # array dimension
 
@@ -389,8 +389,8 @@ class kkr_jij_wc(WorkChain):
         # set optional Jij parameters
         # i and j index for Jij calculation in internal units
         # uses site index (i.e. needs to be <=10)
-        JIJSITEI = self.ctx.wf_dict['jijsite_i']
-        JIJSITEJ = self.ctx.wf_dict['jijsite_j']
+        JIJSITEI = self.ctx.wf_dict.get('jijsite_i')
+        JIJSITEJ = self.ctx.wf_dict.get('jijsite_j')
         if JIJSITEI is not None:
             if JIJSITEJ is None:
                 JIJSITEJ = JIJSITEI
@@ -406,7 +406,7 @@ class kkr_jij_wc(WorkChain):
         """
 
         # Jij radius in Ang.
-        jijrad_ang = self.ctx.wf_dict['jijrad_ang']
+        jijrad_ang = self.ctx.wf_dict.get('jijrad_ang')
 
         # find structure from calculation
         struc, _ = find_parent_structure(self.ctx.parent_calc)
@@ -436,30 +436,24 @@ def _make_nonco_angles(parent_remote):
     Nsites = len(get_sites(structure))
 
     # create nonco angles for m||z
-    init_angles_z = Dict(
-        dict={
-            'fix_dir': [True for i in range(Nsites)],
-            'theta': [0.0 for i in range(Nsites)],
-            'phi': [0.0 for i in range(Nsites)],
-        }
-    )
+    init_angles_z = Dict({
+        'fix_dir': [True for i in range(Nsites)],
+        'theta': [0.0 for i in range(Nsites)],
+        'phi': [0.0 for i in range(Nsites)],
+    })
 
     # create nonco angles for m||x
-    init_angles_x = Dict(
-        dict={
-            'fix_dir': [True for i in range(Nsites)],
-            'theta': [90.0 for i in range(Nsites)],
-            'phi': [0.0 for i in range(Nsites)],
-        }
-    )
+    init_angles_x = Dict({
+        'fix_dir': [True for i in range(Nsites)],
+        'theta': [90.0 for i in range(Nsites)],
+        'phi': [0.0 for i in range(Nsites)],
+    })
 
     # create nonco angles for m||y
-    init_angles_y = Dict(
-        dict={
-            'fix_dir': [True for i in range(Nsites)],
-            'theta': [90.0 for i in range(Nsites)],
-            'phi': [90.0 for i in range(Nsites)],
-        }
-    )
+    init_angles_y = Dict({
+        'fix_dir': [True for i in range(Nsites)],
+        'theta': [90.0 for i in range(Nsites)],
+        'phi': [90.0 for i in range(Nsites)],
+    })
 
     return {'init_angles_x': init_angles_x, 'init_angles_y': init_angles_y, 'init_angles_z': init_angles_z}
