@@ -1,7 +1,5 @@
 #!/usr/bin/env python
 
-from __future__ import absolute_import
-from __future__ import print_function
 from builtins import object
 import pytest
 from aiida.engine import run, run_get_node
@@ -45,7 +43,7 @@ class Test_kkr_calculation(object):
         # extract and update KKR parameter (add missing values)
         params = kkrparams(**voro_calc.inputs.parameters.get_dict())
         params.set_multiple_values(RMAX=7., GMAX=65.)
-        params_node = Dict(dict=params.get_dict())
+        params_node = Dict(params.get_dict())
 
         options = {'resources': {'num_machines': 1, 'tot_num_mpiprocs': 1}, 'queue_name': queuename}
         builder = KkrCalculation.get_builder()
@@ -73,7 +71,7 @@ class Test_kkr_calculation(object):
         # extract and update KKR parameter (add missing values)
         params = kkrparams(**voro_calc.inputs.parameters.get_dict())
         params.set_multiple_values(RMAX=7., GMAX=65.)
-        params_node = Dict(dict=params.get_dict())
+        params_node = Dict(params.get_dict())
 
         options = {'resources': {'num_machines': 1, 'tot_num_mpiprocs': 1}, 'queue_name': queuename}
         builder = KkrCalculation.get_builder()
@@ -138,10 +136,10 @@ class Test_kkr_calculation(object):
         params_node = kkr_calc.inputs.parameters
         params = params_node.get_dict()
         params['RUNOPT'] = ['KKRFLEX']
-        params_node = Dict(dict=params)
+        params_node = Dict(params)
 
         # create an impurity_info node
-        imp_info = Dict(dict={'Rcut': 1.01, 'ilayer_center': 0, 'Zimp': [29.]})
+        imp_info = Dict({'Rcut': 1.01, 'ilayer_center': 0, 'Zimp': [29.]})
 
         options = {'resources': {'num_machines': 1, 'tot_num_mpiprocs': 1}, 'queue_name': queuename}
         builder = KkrCalculation.get_builder()
@@ -217,7 +215,7 @@ class Test_kkr_calculation(object):
         builder = KkrCalculation.get_builder()
         builder.code = kkrhost_local_code
         builder.metadata.options = options
-        builder.parameters = Dict(dict=p)
+        builder.parameters = Dict(p)
         builder.parent_folder = voro_with_kkr_input.outputs.remote_folder
 
         # now run or load from cached data
@@ -273,10 +271,10 @@ class Test_kkr_calculation(object):
         params_node = kkr_calc.inputs.parameters
         params = params_node.get_dict()
         params['RUNOPT'] = ['KKRFLEX']
-        params_node = Dict(dict=params)
+        params_node = Dict(params)
 
         # create an impurity_info node
-        imp_info = Dict(dict={'imp_cls': []})
+        imp_info = Dict({'imp_cls': []})
 
         options = {'resources': {'num_machines': 1, 'tot_num_mpiprocs': 1}, 'queue_name': queuename}
         builder = KkrCalculation.get_builder()
