@@ -1,7 +1,5 @@
 #!/usr/bin/env python
 
-from __future__ import absolute_import
-from __future__ import print_function
 from builtins import object
 import pytest
 from aiida.manage.tests.pytest_fixtures import clear_database, clear_database_after_test, aiida_profile
